@@ -148,7 +148,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                     Self { db_client, client_context_provider }
                 }
 
-                pub async fn new_context<#common_lifetime>(&#common_lifetime self) -> Result<MasterContext<#common_lifetime, #context_type_name #ty_generics>, Error> {
+                pub async fn new_context<#common_lifetime>(&#common_lifetime self) -> Result<MasterContext<#common_lifetime, super::#context_type_name #ty_generics>, Error> {
                     let client_ctx = self.client_context_provider.new_context().await?;
                     Ok(MasterContext::new(client_ctx, &self.db_client))
                 }
